render_system

Function render_system 

pub fn render_system(
    world: &mut World,
    state: &mut SystemState<Query<'_, '_, (&ViewTarget, &ExtractedCamera)>>,
)
The main render system that drives the rendering process. This system runs the RenderGraph schedule, runs any finalization commands like screenshot captures and GPU readbacks, and calls present on swap chains that need to be presented.